/**
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 */

const codecept = require('codeceptjs')
const url = require('node:url')
const { getFilestorageId } = require('./soap/services/util')

module.exports = {

  getLoginTimeout () {
    const { helpers: { AppSuite, Playwright } } = codecept.config.get()
    return AppSuite?.loginTimeout || Playwright?.waitForTimeout / 500 || 20
  },

  getURLRoot () {
    const config = codecept.config.get()
    const driver = config.helpers.Playwright
    const url = driver.url
    const pathArray = url.split('/')
    const protocol = pathArray[0]
    const host = pathArray[2]
    const appRoot = pathArray[3] ? `/${pathArray[3]}` : ''
    return `${protocol}//${host}${appRoot}`
  },

  getServerURL () {
    const config = codecept.config.get()
    const driver = config.helpers.Playwright
    const ox = config.helpers.AppSuite
    const url = ox.serverURL || driver.url
    const pathArray = url.split('/')
    const protocol = pathArray[0]
    const host = pathArray[2]
    return `${protocol}//${host}`
  },

  getJavascriptRoot () {
    const config = codecept.config.get()
    return new url.URL(config.helpers.Playwright.url).pathname
  },

  userContextId () {
    const ox = codecept.config.get().helpers.AppSuite
    return typeof ox.contextId === 'undefined' ? Math.floor(Date.now() / 1000) : ox.contextId
  },

  admin () {
    return codecept.config.get().helpers.AppSuite.admin
  },

  mxDomain () {
    const ox = codecept.config.get().helpers.AppSuite
    return ox.mxDomain || 'example.com'
  },

  smtpServer () {
    const ox = codecept.config.get().helpers.AppSuite
    return ox.smtpServer || 'localhost'
  },

  imapServer () {
    const ox = codecept.config.get().helpers.AppSuite
    return ox.imapServer || 'localhost'
  },

  getDefaultUserPassword () {
    const ox = codecept.config.get().helpers.AppSuite
    return ox.defaultUserPassword || 'secret'
  },

  async getContextFilestorageId () {
    const ox = codecept.config.get().helpers.AppSuite
    return ox.filestoreId || String(await getFilestorageId())
  },

  PropagatedError: class PropagatedError extends Error {
    constructor (error) {
      super(error.message)
      this.name = this.constructor.name
      if (!error) throw new Error('PropagateError needs an error')
      this.original_error = error
      this.stack_before_rethrow = this.stack
      const messageLines = (this.message.match(/\n/g) || []).length + 1
      this.stack = this.stack.split('\n').slice(0, messageLines + 1).join('\n') + '\n' + error.stack
    }
  },

  addJitter (id) {
    const [JITTER_MIN, JITTER_MAX] = [1000, 5000]
    return Math.trunc(id) + Math.floor(Math.random() * (JITTER_MAX - JITTER_MIN + 1) + JITTER_MIN)
  }

}
