const { default: axios } = require('axios')
const jwt = require('jsonwebtoken')

class SuiteService {
  constructor (options) {
    const token = jwt.sign({ sub: 'codecept-helpers' }, options?.jwtSecret, { expiresIn: '1h' })

    this.project = options.project
    this.reference = options.reference
    this.suiteName = options.suiteName
    this.partitionId = options.partitionId
    this.nodePrefix = options.nodePrefix
    this.partitionPrefix = options.partitionPrefix

    this.httpClient = axios.create({
      baseURL: options.suiteServiceUrl,
      headers: {
        authorization: `Bearer ${token}`
      }
    })
  }

  async fullSuite () {
    try {
      const response = await this.httpClient.get(`projects/${this.project}/refs/${this.reference}/suites/${this.suiteName}`)
      return response.data
    } catch (error) {
      if (error?.response?.status === 404) return { tests: [], locked: false }
      throw new Error(error)
    }
  }

  async referenceExists (reference) {
    try {
      const response = await this.httpClient.head(`projects/${this.project}/refs/${reference}/suites/${this.suiteName}`)
      return response.status === 200
    } catch (error) {
      if (error?.response?.status === 404) return false
      throw new Error(error)
    }
  }

  async cloneReferenceFrom (fallbackReference) {
    if (!(await this.referenceExists(fallbackReference))) return

    const { data: { tests } } = await this.httpClient.get(`projects/${this.project}/refs/${fallbackReference}/suites/${this.suiteName}`)
    await this.postPartition({ tests: tests.map(test => Object.assign({}, test, { state: 'new' })) })
  }

  async getPartition (nodeIndex) {
    try {
      const response = await this.httpClient.get(`partitions/${this.partitionPrefix}${this.partitionId}/suites/${this.suiteName}/nodes/${this.nodePrefix}${nodeIndex}`)
      return response.data
    } catch (error) {
      if (error?.response?.status === 404) return []
      throw new Error(error)
    }
  }

  postNodePartition ({ tests, nodeIndex }) {
    if (!tests?.length) {
      throw new Error('No tests to upload for partition')
    }
    return this.httpClient.post(`partitions/${this.partitionPrefix}${this.partitionId}/suites/${this.suiteName}/nodes/`, { nodeIndex: `${this.nodePrefix}${nodeIndex}`, tests })
  }

  postPartition ({ tests }) {
    if (!tests?.length) {
      throw new Error('No tests to upload for partition')
    }
    return this.httpClient.post(`projects/${this.project}/refs/${this.reference}/suites/${this.suiteName}/partitions`, tests)
  }

  postNewTests ({ newTests }) {
    if (!newTests.length) return
    const body = newTests.map(test => Object.assign({ enabled: false, state: 'new' }, test))

    return this.httpClient.post(`projects/${this.project}/refs/${this.reference}/suites/${this.suiteName}/partitions`, body)
  }
}
module.exports = SuiteService
