import { createServer } from 'vite'
import { describe, it, afterEach } from 'vitest'
import vitePluginProxy from '../../dist/index'
import { getPort, http2Request, updateRequestManager } from '../util'

const __dirname = import.meta.dirname
process.noDeprecation = true

describe('detect dev server', () => {
  afterEach(async () => {
    updateRequestManager()
  })

  it('works', async () => {
    const server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy()]
    })
    const PORT = await getPort()
    await server.listen(PORT)

    // need to launch a request to trigger own server detection
    await http2Request(`http://localhost:${PORT}/index.js`)
    await server.close()
  })

  it('works with all hosts config', async () => {
    const server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy()],
      server: {
        host: '0.0.0.0'
      }
    })

    const PORT = await getPort()
    await server.listen(PORT)

    // need to launch a request to trigger own server detection
    await http2Request(`http://0.0.0.0:${PORT}/index.js`)
    await server.close()
  })

  it('works with all hosts config ipv6', async () => {
    const server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy()],
      server: {
        host: '::'
      }
    })

    const PORT = await getPort()
    await server.listen(PORT)

    // need to launch a request to trigger own server detection
    await http2Request(`http://localhost:${PORT}/index.js`)
    await server.close()
  })
})
